@@ -14,8 +14,9 @@ def _copy_to_file(raster, out_file):
 
     """
     try:
-        out_ds = raster._gdal_driver.CreateCopy(out_file, raster._gdal_dataset, strict=0)
-        out_ds = None
+        raster._gdal_driver.CopyFiles(out_file, raster._file)
+        # out_ds = raster._gdal_driver.CreateCopy(out_file, raster._gdal_dataset, strict=0)
+        # out_ds = None
         return 0
     except RuntimeError:
         return 1
@@ -42,11 +43,17 @@ class TempFile(File):
             pass
 
 
-class ShapeTempFile(TempFile):
+class NamedTempFile(TempFile):
+
+    def __init__(self, extension):
+        self.name = os.path.join(gettempdir(), str(uuid.uuid4()))
+        super().__init__(self.name + "." + extension)
+
+
+class ShapeTempFile(NamedTempFile):
 
     def __init__(self):
-        self.name = os.path.join(gettempdir(), str(uuid.uuid4()))
-        super().__init__(self.name + ".shp")
+        super().__init__("shp")
 
     def __del__(self):
         super().__del__()
